@@ -1,13 +1,21 @@
 #!/usr/bin/env python3
 
 '''
-github.com/fitzy1293/redditsfinder
-TO DO:
-    - REFACTOR getPosts. Name it something more appropriate relating to the fact that it gets the pushshift data.
-        #Done
-    - Implement argparse instead of doing sys.argv[] conditions. Just learned about it and it is clearly much better.
-        - Easily can do things like allow arbitrary numbers of users to be entered in one command.
+              _     _ _ _        __ _           _
+ _ __ ___  __| | __| (_) |_ ___ / _(_)_ __   __| | ___ _ __
+| '__/ _ \/ _` |/ _` | | __/ __| |_| | '_ \ / _` |/ _ \ '__|
+| | |  __/ (_| | (_| | | |_\__ \  _| | | | | (_| |  __/ |
+|_|  \___|\__,_|\__,_|_|\__|___/_| |_|_| |_|\__,_|\___|_|
 
+
+github.com/fitzy1293/redditsfinder
+
+
+TO DO:
+    - Add more optional args.
+    - Instead of using a set to identify pictures:
+        - name_com_extension
+            -What if invalid extension?
 '''
 
 import urllib.request
@@ -62,7 +70,7 @@ def cleanupPostData(postData, postType): #Thanks /u/kwelzel for helping me refac
 #─────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────
 def getPosts(user, postType): # Pushshift API requests in chunks of 100
     console = Console()
-    console.print(f'[bold blue]{postType[0].upper()}{postType[1:]} request log:')
+    console.print(f'[bold blue underline]{postType[0].upper()}{postType[1:]} request log:')
 
     apiUrl = 'https://api.pushshift.io/reddit/search/'
     postSetMaxLen = 100 # Max num of posts in each pushshift request, seems to be 100 right now or it breaks.
@@ -76,7 +84,7 @@ def getPosts(user, postType): # Pushshift API requests in chunks of 100
     else:
         highlight = '[magenta]'
 
-    ct, testCt = 0, 0
+    ct = 0
 
     posts = []
     while True:
@@ -92,11 +100,8 @@ def getPosts(user, postType): # Pushshift API requests in chunks of 100
             before = postData['created_utc']
             yield cleanupPostData(postData, postType)
 
-        #testCt+=1 #For testing.
-        #if testCt>1: break
-
         ct = ct + len(data)
-        console.print(f'[red]\t{ct} {highlight}{url}')
+        console.print(f'[bold green]\t{ct} {highlight}{url}')
 
         if len(data) < postSetMaxLen:
             break
@@ -159,22 +164,18 @@ def run(args, user):
 
     console.print(f'[bold blue]\nGathering and formatting data from pushshift for {user}.\n')
 
-    if  args['pics']:
+    if  '-pics' in args:
         keyType = {'submission': ('url', 'created_utc',)}
         images = imageUrls(user, [i for i in getPosts(user, 'submission')])
 
         images = set(open(os.path.join(userDir,'images.txt')).read().splitlines())
-        imageStatus = '\n'.join([f'[red]{i+1}\t[magenta]{image}' for i, image in enumerate(images)])
-        imageSubmissionLog = f'[bold blue]\nImages submitted by {user}\n{imageStatus}'
+        imageStatus = '\n'.join([f'\t[bold green]{i+1} [cyan]{image}' for i, image in enumerate(images)])
+        imageSubmissionLog = f'[bold blue underline]\nImages submitted by {user}:[/bold blue underline]\n{imageStatus}'
         console.print(imageSubmissionLog)
 
-        if args['download']:
+        if not '-d' in args and not '--download' in args:
             print()
             imagesdl(images, userDir)
-        if not args['quiet']:
-            fnamesStr = '\n\t' + '\n\t'.join([i for i in os.listdir(userDir)])
-            console.print(f'\n[bold cyan]{userDir}{fnamesStr}')
-            console.print(f'\n[bold blue]Run time - {round(time.time() - start, 1)} s\n')
 
     else:
         allPosts = {'comments': [i for i in getPosts(user, 'comment')],
@@ -183,7 +184,7 @@ def run(args, user):
         postCounts = countPosts(allPosts)
         writeFiles(allPosts, postCounts, user, userDir)
 
-        if not args['quiet']:
+        if not '-q' in args and not '--quiet' in args:
             tablesDict = {'postCounts': postCounts,
                           'commentsLen': str( len(allPosts['comments']) ),
                           'submissionsLen': str( len(allPosts['submissions']) ),
@@ -192,20 +193,30 @@ def run(args, user):
                           'end': time.time(),
                           'user':user}
             printTotals(tablesDict)
+
+    if not '-q' in args and not '--quiet' in args:
+        fnamesStr = '\n\t' + '\n\t'.join([i for i in os.listdir(userDir)])
+        console.print(f'\n[bold cyan underline]{userDir}{fnamesStr}')
+        console.print(f'\n[bold blue]Run time - {round(time.time() - start, 1)} s\n')
 #─────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────
 #=============================================================================================================================
 #─────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────
 def main():  # System arguments
-    parser = argparse.ArgumentParser()
-    parser.add_argument('-pics', action='store_true', dest='pics', help='Returns image urls in users/user/images.txt')
-    parser.add_argument('-d', '--download',action='store_true', dest='download', help='Downloads pics from images.txt')
-    parser.add_argument('-q,' '--quiet', action='store_true', dest='quiet', help='Silences non log related outputs')
-    parser.add_argument(' ', action='append', type=str, nargs='+')
+    #SOME REDDIT ACCOUNTS HAVE "-" at the beginning of their usernames.
+    #WHY?????? IT RUINS ARGSPARSE. TRIED TESTING WITH A LIST OF MANY USERNAMES AND FAILED.
 
-    if len(sys.argv) == 1:
-        print('Remember to add at least 1 username')
-        print('Try redditsfinder -h for help')
+    redditsfinderArgs = sys.argv[1:]
+    optionalArgs = ('-pics', '-d', '--download', '-q', '--quiet', '-f')
+    enteredOptionalArgs = [i for i in redditsfinderArgs if i in optionalArgs]
 
-    usableArgs = vars(parser.parse_args())
-    for user in usableArgs[' '][0]:
-        run(usableArgs, user)
+    if '-f' in enteredOptionalArgs:
+        usernames = open(sys.argv[-1]).read().splitlines()
+    else:
+        usernames = [i for i in redditsfinderArgs if i not in optionalArgs]
+
+
+    print(f'Optional arguments: {enteredOptionalArgs}')
+    print('Usernames: '), pprint(usernames)
+
+    for user in usernames:
+        run(enteredOptionalArgs, user)
